@@ -15,26 +15,28 @@
 # limitations under the License.
 #
 
+import warnings
 from ai.h2o.sparkling.SharedBackendConfUtils import SharedBackendConfUtils
 
+
 class SharedBackendConf(SharedBackendConfUtils):
 
     #
     # Getters
     #
 
-    def backendClusterMode(self):
-        return self._jconf.backendClusterMode()
+    def jks(self):
+        return self._get_option(self._jconf.jks())
 
     def cloudName(self):
         return self._get_option(self._jconf.cloudName())
 
-    def nthreads(self):
-        return self._jconf.nthreads()
-
     def isH2OReplEnabled(self):
         return self._jconf.isH2OReplEnabled()
 
+    def backendClusterMode(self):
+        return self._jconf.backendClusterMode()
+
     def scalaIntDefaultNum(self):
         return self._jconf.scalaIntDefaultNum()
 
@@ -47,9 +49,6 @@ class SharedBackendConf(SharedBackendConfUtils):
     def isFailOnUnsupportedSparkParamEnabled(self):
         return self._jconf.isFailOnUnsupportedSparkParamEnabled()
 
-    def jks(self):
-        return self._get_option(self._jconf.jks())
-
     def jksPass(self):
         return self._get_option(self._jconf.jksPass())
 
@@ -83,8 +82,14 @@ class SharedBackendConf(SharedBackendConfUtils):
     def h2oNodeLogLevel(self):
         return self._jconf.h2oNodeLogLevel()
 
+    def logLevel(self):
+        return self._jconf.logLevel()
+
     def h2oNodeLogDir(self):
-        return self._jconf.h2oNodeLogDir()
+        return self._get_option(self._jconf.h2oNodeLogDir())
+
+    def logDir(self):
+        return self._get_option(self._jconf.logDir())
 
     def backendHeartbeatInterval(self):
         return self._jconf.backendHeartbeatInterval()
@@ -110,15 +115,21 @@ class SharedBackendConf(SharedBackendConfUtils):
     def internalPortOffset(self):
         return self._jconf.internalPortOffset()
 
-    def mojoDestroyTimeout(self):
-        return self._jconf.mojoDestroyTimeout()
-
     def nodeBasePort(self):
         return self._jconf.nodeBasePort()
 
+    def basePort(self):
+        return self._jconf.basePort()
+
+    def mojoDestroyTimeout(self):
+        return self._jconf.mojoDestroyTimeout()
+
     def nodeExtraProperties(self):
         return self._get_option(self._jconf.nodeExtraProperties())
 
+    def extraProperties(self):
+        return self._get_option(self._jconf.extraProperties())
+
     def flowExtraHttpHeaders(self):
         return self._get_option(self._jconf.flowExtraHttpHeaders())
 
@@ -176,10 +187,6 @@ class SharedBackendConf(SharedBackendConfUtils):
     def isKerberizedHiveEnabled(self):
         return self._jconf.isKerberizedHiveEnabled()
 
-    def isHiveSupportEnabled(self):
-        warnings.warn("The method 'isHiveSupportEnabled' is deprecated and will be removed in 3.32. Use 'isKerberizedHiveEnabled' instead!")
-        return self.isKerberizedHiveEnabled()
-
     def hiveHost(self):
         return self._get_option(self._jconf.hiveHost())
 
@@ -192,6 +199,16 @@ class SharedBackendConf(SharedBackendConfUtils):
     def hiveToken(self):
         return self._get_option(self._jconf.hiveToken())
 
+    def icedDir(self):
+        return self._get_option(self._jconf.icedDir())
+
+    def restApiTimeout(self):
+        return self._jconf.restApiTimeout()
+
+    def nthreads(self):
+        return self._jconf.nthreads()
+
+
     #
     # Setters
     #
@@ -204,12 +221,12 @@ class SharedBackendConf(SharedBackendConfUtils):
         self._jconf.setExternalClusterMode()
         return self
 
-    def setCloudName(self, cloudName):
-        self._jconf.setCloudName(cloudName)
+    def setCloudName(self, value):
+        self._jconf.setCloudName(value)
         return self
 
-    def setNthreads(self, nthreads):
-        self._jconf.setNthreads(nthreads)
+    def setNthreads(self, value):
+        self._jconf.setNthreads(value)
         return self
 
     def setReplEnabled(self):
@@ -220,8 +237,8 @@ class SharedBackendConf(SharedBackendConfUtils):
         self._jconf.setReplDisabled()
         return self
 
-    def setDefaultNumReplSessions(self, numSessions):
-        self._jconf.setDefaultNumReplSessions(numSessions)
+    def setDefaultNumReplSessions(self, value):
+        self._jconf.setDefaultNumReplSessions(value)
         return self
 
     def setClusterTopologyListenerEnabled(self):
@@ -248,16 +265,16 @@ class SharedBackendConf(SharedBackendConfUtils):
         self._jconf.setFailOnUnsupportedSparkParamDisabled()
         return self
 
-    def setJks(self, path):
-        self._jconf.setJks(path)
+    def setJks(self, value):
+        self._jconf.setJks(value)
         return self
 
-    def setJksPass(self, password):
-        self._jconf.setJksPass(password)
+    def setJksPass(self, value):
+        self._jconf.setJksPass(value)
         return self
 
-    def setJksAlias(self, alias):
-        self._jconf.setJksAlias(alias)
+    def setJksAlias(self, value):
+        self._jconf.setJksAlias(value)
         return self
 
     def setHashLoginEnabled(self):
@@ -284,20 +301,20 @@ class SharedBackendConf(SharedBackendConfUtils):
         self._jconf.setKerberosLoginDisabled()
         return self
 
-    def setLoginConf(self, filePath):
-        self._jconf.setLoginConf(filePath)
+    def setLoginConf(self, value):
+        self._jconf.setLoginConf(value)
         return self
 
-    def setUserName(self, username):
-        self._jconf.setUserName(username)
+    def setUserName(self, value):
+        self._jconf.setUserName(value)
         return self
 
-    def setPassword(self, password):
-        self._jconf.setPassword(password)
+    def setPassword(self, value):
+        self._jconf.setPassword(value)
         return self
 
-    def setSslConf(self, path):
-        self._jconf.setSslConf(path)
+    def setSslConf(self, value):
+        self._jconf.setSslConf(value)
         return self
 
     def setAutoFlowSslEnabled(self):
@@ -308,32 +325,40 @@ class SharedBackendConf(SharedBackendConfUtils):
         self._jconf.setAutoFlowSslDisabled()
         return self
 
-    def setH2ONodeLogLevel(self, level):
-        self._jconf.setH2ONodeLogLevel(level)
+    def setH2ONodeLogLevel(self, value):
+        self._jconf.setH2ONodeLogLevel(value)
         return self
 
-    def setH2ONodeLogDir(self, dir):
-        self._jconf.setH2ONodeLogDir(dir)
+    def setLogLevel(self, value):
+        self._jconf.setLogLevel(value)
         return self
 
-    def setBackendHeartbeatInterval(self, interval):
-        self._jconf.setBackendHeartbeatInterval(interval)
+    def setH2ONodeLogDir(self, value):
+        self._jconf.setH2ONodeLogDir(value)
         return self
 
-    def setCloudTimeout(self, timeout):
-        self._jconf.setCloudTimeout(timeout)
+    def setLogDir(self, value):
+        self._jconf.setLogDir(value)
         return self
 
-    def setNodeNetworkMask(self, mask):
-        self._jconf.setNodeNetworkMask(mask)
+    def setBackendHeartbeatInterval(self, value):
+        self._jconf.setBackendHeartbeatInterval(value)
         return self
 
-    def setStacktraceCollectorInterval(self, interval):
-        self._jconf.setStacktraceCollectorInterval(interval)
+    def setCloudTimeout(self, value):
+        self._jconf.setCloudTimeout(value)
         return self
 
-    def setContextPath(self, contextPath):
-        self._jconf.setContextPath(contextPath)
+    def setNodeNetworkMask(self, value):
+        self._jconf.setNodeNetworkMask(value)
+        return self
+
+    def setStacktraceCollectorInterval(self, value):
+        self._jconf.setStacktraceCollectorInterval(value)
+        return self
+
+    def setContextPath(self, value):
+        self._jconf.setContextPath(value)
         return self
 
     def setFlowScalaCellAsyncEnabled(self):
@@ -344,28 +369,36 @@ class SharedBackendConf(SharedBackendConfUtils):
         self._jconf.setFlowScalaCellAsyncDisabled()
         return self
 
-    def setMaxParallelScalaCellJobs(self, limit):
-        self._jconf.setMaxParallelScalaCellJobs(limit)
+    def setMaxParallelScalaCellJobs(self, value):
+        self._jconf.setMaxParallelScalaCellJobs(value)
         return self
 
-    def setInternalPortOffset(self, offset):
-        self._jconf.setInternalPortOffset(offset)
+    def setInternalPortOffset(self, value):
+        self._jconf.setInternalPortOffset(value)
         return self
 
-    def setNodeBasePort(self, port):
-        self._jconf.setNodeBasePort(port)
+    def setNodeBasePort(self, value):
+        self._jconf.setNodeBasePort(value)
         return self
 
-    def setMojoDestroyTimeout(self, timeoutInMilliseconds):
-        self._jconf.setMojoDestroyTimeout(timeoutInMilliseconds)
+    def setBasePort(self, value):
+        self._jconf.setBasePort(value)
         return self
 
-    def setNodeExtraProperties(self, extraProperties):
-        self._jconf.setNodeExtraProperties(extraProperties)
+    def setMojoDestroyTimeout(self, value):
+        self._jconf.setMojoDestroyTimeout(value)
         return self
 
-    def setFlowExtraHttpHeaders(self, headers):
-        self._jconf.setFlowExtraHttpHeaders(headers)
+    def setNodeExtraProperties(self, value):
+        self._jconf.setNodeExtraProperties(value)
+        return self
+
+    def setExtraProperties(self, value):
+        self._jconf.setExtraProperties(value)
+        return self
+
+    def setFlowExtraHttpHeaders(self, value):
+        self._jconf.setFlowExtraHttpHeaders(value)
         return self
 
     def setInternalSecureConnectionsEnabled(self):
@@ -384,32 +417,32 @@ class SharedBackendConf(SharedBackendConfUtils):
         self._jconf.setInsecureXGBoostDenied()
         return self
 
-    def setFlowDir(self, dir):
-        self._jconf.setFlowDir(dir)
+    def setFlowDir(self, value):
+        self._jconf.setFlowDir(value)
         return self
 
-    def setClientIp(self, ip):
-        self._jconf.setClientIp(ip)
+    def setClientIp(self, value):
+        self._jconf.setClientIp(value)
         return self
 
-    def setClientIcedDir(self, icedDir):
-        self._jconf.setClientIcedDir(icedDir)
+    def setClientIcedDir(self, value):
+        self._jconf.setClientIcedDir(value)
         return self
 
-    def setH2OClientLogLevel(self, level):
-        self._jconf.setH2OClientLogLevel(level)
+    def setH2OClientLogLevel(self, value):
+        self._jconf.setH2OClientLogLevel(value)
         return self
 
-    def setH2OClientLogDir(self, dir):
-        self._jconf.setH2OClientLogDir(dir)
+    def setH2OClientLogDir(self, value):
+        self._jconf.setH2OClientLogDir(value)
         return self
 
-    def setClientBasePort(self, basePort):
-        self._jconf.setClientBasePort(basePort)
+    def setClientBasePort(self, value):
+        self._jconf.setClientBasePort(value)
         return self
 
-    def setClientWebPort(self, port):
-        self._jconf.setClientWebPort(port)
+    def setClientWebPort(self, value):
+        self._jconf.setClientWebPort(value)
         return self
 
     def setClientVerboseEnabled(self):
@@ -420,54 +453,54 @@ class SharedBackendConf(SharedBackendConfUtils):
         self._jconf.setClientVerboseDisabled()
         return self
 
-    def setClientNetworkMask(self, mask):
-        self._jconf.setClientNetworkMask(mask)
+    def setClientNetworkMask(self, value):
+        self._jconf.setClientNetworkMask(value)
         return self
 
-    def setClientFlowBaseurlOverride(self, baseUrl):
-        self._jconf.setClientFlowBaseurlOverride(baseUrl)
+    def setClientFlowBaseurlOverride(self, value):
+        self._jconf.setClientFlowBaseurlOverride(value)
         return self
 
-    def setClientCheckRetryTimeout(self, timeout):
-        self._jconf.setClientCheckRetryTimeout(timeout)
+    def setClientCheckRetryTimeout(self, value):
+        self._jconf.setClientCheckRetryTimeout(value)
         return self
 
-    def setClientExtraProperties(self, extraProperties):
-        self._jconf.setClientExtraProperties(extraProperties)
+    def setClientExtraProperties(self, value):
+        self._jconf.setClientExtraProperties(value)
         return self
 
-    def setVerifySslCertificates(self, verify):
-        self._jconf.setVerifySslCertificates(verify)
+    def setVerifySslCertificates(self, value):
+        self._jconf.setVerifySslCertificates(value)
         return self
 
     def setKerberizedHiveEnabled(self):
         self._jconf.setKerberizedHiveEnabled()
         return self
 
-    def setHiveSupportEnabled(self):
-        warnings.warn("The method 'setHiveSupportEnabled' is deprecated and will be removed in 3.32. Use 'setKerberizedHiveEnabled' instead!")
-        return self.setKerberizedHiveEnabled()
-
     def setKerberizedHiveDisabled(self):
         self._jconf.setKerberizedHiveDisabled()
         return self
 
-    def setHiveSupportDisabled(self):
-        warnings.warn("The method 'setHiveSupportDisabled' is deprecated and will be removed in 3.32. Use 'setKerberizedHiveDisabled' instead!")
-        return self.setKerberizedHiveDisabled()
-
-    def setHiveHost(self, host):
-        self._jconf.setHiveHost(host)
+    def setHiveHost(self, value):
+        self._jconf.setHiveHost(value)
         return self
 
-    def setHivePrincipal(self, principal):
-        self._jconf.setHivePrincipal(principal)
+    def setHivePrincipal(self, value):
+        self._jconf.setHivePrincipal(value)
         return self
 
-    def setHiveJdbcUrlPattern(self, pattern):
-        self._jconf.setHiveJdbcUrlPattern(pattern)
+    def setHiveJdbcUrlPattern(self, value):
+        self._jconf.setHiveJdbcUrlPattern(value)
         return self
 
-    def setHiveToken(self, token):
-        self._jconf.setHiveToken(token)
+    def setHiveToken(self, value):
+        self._jconf.setHiveToken(value)
+        return self
+
+    def setIcedDir(self, value):
+        self._jconf.setIcedDir(value)
+        return self
+
+    def setRestApiTimeout(self, value):
+        self._jconf.setRestApiTimeout(value)
         return self
