@@ -50,7 +50,6 @@ class H2OGAMRegressor(H2OGAM):
                  solver="AUTO",
                  alphaValue=None,
                  lambdaValue=None,
-                 startval=None,
                  lambdaSearch=False,
                  earlyStopping=True,
                  nlambdas=-1,
@@ -96,8 +95,7 @@ class H2OGAMRegressor(H2OGAM):
                  stoppingMetric="AUTO",
                  stoppingTolerance=0.001,
                  customMetricFunc=None,
-                 exportCheckpointsDir=None,
-                 aucType="AUTO"):
+                 exportCheckpointsDir=None):
         Initializer.load_sparkling_jar()
         super(H2OGAM, self).__init__()
         self._java_obj = self._new_java_obj("ai.h2o.sparkling.ml.algos.regression.H2OGAMRegressor", self.uid)
